# Reference

Complete reference documentation for Jnkn.

## CLI

- [CLI Overview](cli/index.md) — All commands and global options

## Configuration

- [config.yaml](configuration/jnkn-yaml.md) — Main configuration file
- [.jnknignore](configuration/jnknignore.md) — File exclusion patterns
- [suppressions.yaml](configuration/suppressions-yaml.md) — False positive management

## Patterns

- [Overview](patterns/index.md) — How pattern detection works
- [Python](patterns/python-env-vars.md) — Python environment variable patterns
- [Terraform](patterns/terraform-resources.md) — Terraform resource patterns
- [Kubernetes](patterns/kubernetes-refs.md) — Kubernetes reference patterns

## Output

- [JSON Schema](output-formats/json-schema.md) — Output format specification

## Glossary

- [Glossary](glossary.md) — Terms and definitions
